@@ -18,8 +18,8 @@ import os
 from os.path import abspath, dirname
 currdir = dirname(abspath(__file__))+os.sep
 
-import pyutilib.th as unittest
-from six import StringIO
+import pyomo.common.unittest as unittest
+from io import StringIO
 
 from pyomo.environ import ConcreteModel, AbstractModel, Connector, Var, NonNegativeReals, Set, Constraint, TransformationFactory, Binary, Reals, VarList
 
@@ -283,7 +283,7 @@ class TestConnector(unittest.TestCase):
         os = StringIO()
         m.component('c.expanded').pprint(ostream=os)
         self.assertEqual(os.getvalue(),
-"""c.expanded : Size=1, Index=c.expanded_index, Active=True
+"""c.expanded : Size=1, Index='c.expanded_index', Active=True
     Key : Lower : Body : Upper : Active
       1 :   1.0 :    x :   1.0 :   True
 """)
@@ -317,7 +317,7 @@ class TestConnector(unittest.TestCase):
         os = StringIO()
         m.component('c.expanded').pprint(ostream=os)
         self.assertEqual(os.getvalue(),
-"""c.expanded : Size=2, Index=c.expanded_index, Active=True
+"""c.expanded : Size=2, Index='c.expanded_index', Active=True
     Key : Lower : Body : Upper : Active
       1 :   1.0 :    x :   1.0 :   True
       2 :   1.0 :    y :   1.0 :   True
@@ -352,7 +352,7 @@ class TestConnector(unittest.TestCase):
         os = StringIO()
         m.component('c.expanded').pprint(ostream=os)
         self.assertEqual(os.getvalue(),
-"""c.expanded : Size=2, Index=c.expanded_index, Active=True
+"""c.expanded : Size=2, Index='c.expanded_index', Active=True
     Key : Lower : Body  : Upper : Active
       1 :   1.0 :   - x :   1.0 :   True
       2 :   1.0 : 1 + y :   1.0 :   True
@@ -387,7 +387,7 @@ class TestConnector(unittest.TestCase):
         os = StringIO()
         m.component('c.expanded').pprint(ostream=os)
         self.assertEqual(os.getvalue(),
-"""c.expanded : Size=3, Index=c.expanded_index, Active=True
+"""c.expanded : Size=3, Index='c.expanded_index', Active=True
     Key : Lower : Body : Upper : Active
       1 :   1.0 : x[1] :   1.0 :   True
       2 :   1.0 : x[2] :   1.0 :   True
@@ -429,10 +429,10 @@ class TestConnector(unittest.TestCase):
         os = StringIO()
         m.component('c.expanded').pprint(ostream=os)
         self.assertEqual(os.getvalue(),
-"""c.expanded : Size=2, Index=c.expanded_index, Active=True
-    Key : Lower : Body            : Upper : Active
-      1 :   0.0 : x - ECON.auto.x :   0.0 :   True
-      2 :   0.0 : y - ECON.auto.y :   0.0 :   True
+"""c.expanded : Size=2, Index='c.expanded_index', Active=True
+    Key : Lower : Body              : Upper : Active
+      1 :   0.0 : x - 'ECON.auto.x' :   0.0 :   True
+      2 :   0.0 : y - 'ECON.auto.y' :   0.0 :   True
 """)
 
 
@@ -465,10 +465,10 @@ class TestConnector(unittest.TestCase):
         os = StringIO()
         m.component('c.expanded').pprint(ostream=os)
         self.assertEqual(os.getvalue(),
-"""c.expanded : Size=2, Index=c.expanded_index, Active=True
-    Key : Lower : Body                : Upper : Active
-      1 :   0.0 :   - x - ECON.auto.x :   0.0 :   True
-      2 :   0.0 : 1 + y - ECON.auto.y :   0.0 :   True
+"""c.expanded : Size=2, Index='c.expanded_index', Active=True
+    Key : Lower : Body                  : Upper : Active
+      1 :   0.0 :   - x - 'ECON.auto.x' :   0.0 :   True
+      2 :   0.0 : 1 + y - 'ECON.auto.y' :   0.0 :   True
 """)
 
 
@@ -509,11 +509,11 @@ class TestConnector(unittest.TestCase):
         os = StringIO()
         m.component('c.expanded').pprint(ostream=os)
         self.assertEqual(os.getvalue(),
-"""c.expanded : Size=3, Index=c.expanded_index, Active=True
-    Key : Lower : Body                  : Upper : Active
-      1 :   0.0 : x[1] - ECON.auto.x[1] :   0.0 :   True
-      2 :   0.0 : x[2] - ECON.auto.x[2] :   0.0 :   True
-      3 :   0.0 :       y - ECON.auto.y :   0.0 :   True
+"""c.expanded : Size=3, Index='c.expanded_index', Active=True
+    Key : Lower : Body                    : Upper : Active
+      1 :   0.0 : x[1] - 'ECON.auto.x'[1] :   0.0 :   True
+      2 :   0.0 : x[2] - 'ECON.auto.x'[2] :   0.0 :   True
+      3 :   0.0 :       y - 'ECON.auto.y' :   0.0 :   True
 """)
 
     def test_expand_multiple_empty_indexed(self):
@@ -564,21 +564,21 @@ class TestConnector(unittest.TestCase):
         os = StringIO()
         m.component('c.expanded').pprint(ostream=os)
         self.assertEqual(os.getvalue(),
-"""c.expanded : Size=3, Index=c.expanded_index, Active=True
-    Key : Lower : Body                   : Upper : Active
-      1 :   0.0 : x[1] - ECON1.auto.x[1] :   0.0 :   True
-      2 :   0.0 : x[2] - ECON1.auto.x[2] :   0.0 :   True
-      3 :   0.0 :       y - ECON1.auto.y :   0.0 :   True
+"""c.expanded : Size=3, Index='c.expanded_index', Active=True
+    Key : Lower : Body                     : Upper : Active
+      1 :   0.0 : x[1] - 'ECON1.auto.x'[1] :   0.0 :   True
+      2 :   0.0 : x[2] - 'ECON1.auto.x'[2] :   0.0 :   True
+      3 :   0.0 :       y - 'ECON1.auto.y' :   0.0 :   True
 """)
 
         os = StringIO()
         m.component('d.expanded').pprint(ostream=os)
         self.assertEqual(os.getvalue(),
-"""d.expanded : Size=3, Index=d.expanded_index, Active=True
-    Key : Lower : Body                              : Upper : Active
-      1 :   0.0 : ECON2.auto.x[1] - ECON1.auto.x[1] :   0.0 :   True
-      2 :   0.0 : ECON2.auto.x[2] - ECON1.auto.x[2] :   0.0 :   True
-      3 :   0.0 :       ECON2.auto.y - ECON1.auto.y :   0.0 :   True
+"""d.expanded : Size=3, Index='d.expanded_index', Active=True
+    Key : Lower : Body                                  : Upper : Active
+      1 :   0.0 : 'ECON2.auto.x'[1] - 'ECON1.auto.x'[1] :   0.0 :   True
+      2 :   0.0 : 'ECON2.auto.x'[2] - 'ECON1.auto.x'[2] :   0.0 :   True
+      3 :   0.0 :       'ECON2.auto.y' - 'ECON1.auto.y' :   0.0 :   True
 """)
 
 
@@ -624,7 +624,7 @@ class TestConnector(unittest.TestCase):
         os = StringIO()
         m.component('c.expanded').pprint(ostream=os)
         self.assertEqual(os.getvalue(),
-"""c.expanded : Size=3, Index=c.expanded_index, Active=True
+"""c.expanded : Size=3, Index='c.expanded_index', Active=True
     Key : Lower : Body         : Upper : Active
       1 :   0.0 : x[1] - a2[1] :   0.0 :   True
       2 :   0.0 : x[2] - a2[2] :   0.0 :   True
@@ -634,7 +634,7 @@ class TestConnector(unittest.TestCase):
         os = StringIO()
         m.component('d.expanded').pprint(ostream=os)
         self.assertEqual(os.getvalue(),
-"""d.expanded : Size=3, Index=d.expanded_index, Active=True
+"""d.expanded : Size=3, Index='d.expanded_index', Active=True
     Key : Lower : Body          : Upper : Active
       1 :   0.0 : a1[1] - a2[1] :   0.0 :   True
       2 :   0.0 : a1[2] - a2[2] :   0.0 :   True
@@ -683,8 +683,8 @@ class TestConnector(unittest.TestCase):
         self.assertEqual(os.getvalue(),
 """ECON1 : Size=1, Index=None
     Key  : Name : Size : Variable
-    None :    x :    2 :           a2
-         :    y :    1 : ECON1.auto.y
+    None :    x :    2 :             a2
+         :    y :    1 : 'ECON1.auto.y'
 """)
 
         self.assertEqual(len(list(m.component_objects(Constraint))), 5)
@@ -698,21 +698,21 @@ class TestConnector(unittest.TestCase):
         os = StringIO()
         m.component('c.expanded').pprint(ostream=os)
         self.assertEqual(os.getvalue(),
-"""c.expanded : Size=3, Index=c.expanded_index, Active=True
-    Key : Lower : Body             : Upper : Active
-      1 :   0.0 :     x[1] - a2[1] :   0.0 :   True
-      2 :   0.0 :     x[2] - a2[2] :   0.0 :   True
-      3 :   0.0 : y - ECON1.auto.y :   0.0 :   True
+"""c.expanded : Size=3, Index='c.expanded_index', Active=True
+    Key : Lower : Body               : Upper : Active
+      1 :   0.0 :       x[1] - a2[1] :   0.0 :   True
+      2 :   0.0 :       x[2] - a2[2] :   0.0 :   True
+      3 :   0.0 : y - 'ECON1.auto.y' :   0.0 :   True
 """)
 
         os = StringIO()
         m.component('d.expanded').pprint(ostream=os)
         self.assertEqual(os.getvalue(),
-"""d.expanded : Size=3, Index=d.expanded_index, Active=True
-    Key : Lower : Body                   : Upper : Active
-      1 :   0.0 : ECON2.auto.x[1] - x[1] :   0.0 :   True
-      2 :   0.0 : ECON2.auto.x[2] - x[2] :   0.0 :   True
-      3 :   0.0 :                 b1 - y :   0.0 :   True
+"""d.expanded : Size=3, Index='d.expanded_index', Active=True
+    Key : Lower : Body                     : Upper : Active
+      1 :   0.0 : 'ECON2.auto.x'[1] - x[1] :   0.0 :   True
+      2 :   0.0 : 'ECON2.auto.x'[2] - x[2] :   0.0 :   True
+      3 :   0.0 :                   b1 - y :   0.0 :   True
 """)
 
 
@@ -751,19 +751,19 @@ class TestConnector(unittest.TestCase):
         os = StringIO()
         m.component('c.expanded').pprint(ostream=os)
         self.assertEqual(os.getvalue(),
-"""c.expanded : Size=2, Index=c.expanded_index, Active=True
-    Key : Lower : Body                      : Upper : Active
-      1 :   0.0 : flow[1] - ECON1.auto.flow :   0.0 :   True
-      2 :   0.0 :  phase - ECON1.auto.phase :   0.0 :   True
+"""c.expanded : Size=2, Index='c.expanded_index', Active=True
+    Key : Lower : Body                        : Upper : Active
+      1 :   0.0 : flow[1] - 'ECON1.auto.flow' :   0.0 :   True
+      2 :   0.0 :  phase - 'ECON1.auto.phase' :   0.0 :   True
 """)
 
         os = StringIO()
         m.component('d.expanded').pprint(ostream=os)
         self.assertEqual(os.getvalue(),
-"""d.expanded : Size=2, Index=d.expanded_index, Active=True
-    Key : Lower : Body                      : Upper : Active
-      1 :   0.0 : ECON2.auto.flow - flow[2] :   0.0 :   True
-      2 :   0.0 :  ECON2.auto.phase - phase :   0.0 :   True
+"""d.expanded : Size=2, Index='d.expanded_index', Active=True
+    Key : Lower : Body                        : Upper : Active
+      1 :   0.0 : 'ECON2.auto.flow' - flow[2] :   0.0 :   True
+      2 :   0.0 :  'ECON2.auto.phase' - phase :   0.0 :   True
 """)
 
         os = StringIO()
@@ -799,7 +799,7 @@ class TestConnector(unittest.TestCase):
         os = StringIO()
         m.component('eq.expanded').pprint(ostream=os)
         self.assertEqual(os.getvalue(),
-"""eq.expanded : Size=1, Index=eq.expanded_index, Active=True
+"""eq.expanded : Size=1, Index='eq.expanded_index', Active=True
     Key : Lower : Body  : Upper : Active
       1 :   0.0 : x - y :   0.0 :   True
 """)
